summaryrefslogtreecommitdiffhomepage
path: root/dev/kernel/FSKit
diff options
context:
space:
mode:
Diffstat (limited to 'dev/kernel/FSKit')
-rw-r--r--dev/kernel/FSKit/HeFS.h18
-rw-r--r--dev/kernel/FSKit/NeFS.h9
2 files changed, 11 insertions, 16 deletions
diff --git a/dev/kernel/FSKit/NeFS.h b/dev/kernel/FSKit/NeFS.h
index 425ab051..2235ca4f 100644
--- a/dev/kernel/FSKit/NeFS.h
+++ b/dev/kernel/FSKit/NeFS.h
@@ -31,6 +31,8 @@ default.
#define kNeFSInvalidCatalog (-1)
#define kNeFSCatalogNameLen (256)
+#define kNeFSVolumeName "NeFS Volume"
+
#define kNeFSMinimumDiskSize (mib_cast(8))
#define kNeFSSectorSz (512)
@@ -305,11 +307,8 @@ class NeFileSystemParser final {
/// @brief Make a EPM+NeFS drive out of the disk.
/// @param drive The drive to write on.
/// @return If it was sucessful, see err_local_get().
- _Output Bool FormatEPM(_Input _Output DriveTrait* drive, _Input const Lba end_lba,
- _Input const Int32 flags, const Char* part_name);
-
- _Output Bool FormatGPT(_Input _Output DriveTrait* drive, _Input const Lba end_lba,
- _Input const Int32 flags, const Char* part_name);
+ _Output Bool Format(_Input _Output DriveTrait* drive, _Input const Int32 flags,
+ const Char* part_name);
public:
UInt32 mDriveIndex{kNeFSSubDriveA};
diff --git a/dev/kernel/FSKit/HeFS.h b/dev/kernel/FSKit/HeFS.h
index e4da9a47..63725f04 100644
--- a/dev/kernel/FSKit/HeFS.h
+++ b/dev/kernel/FSKit/HeFS.h
@@ -100,7 +100,7 @@ struct PACKED HEFS_BOOT_NODE final {
Kernel::UInt64 fSectorCount; /// @brief Number of sectors in the filesystem.
Kernel::UInt64 fSectorSize; /// @brief Size of the sector.
Kernel::UInt32 fChecksum; /// @brief Checksum of the boot node.
- Kernel::UInt8 fDriveKind; /// @brief Kind of the drive. (Hard Drive, Solid State Drive, Optical
+ Kernel::UInt8 fDiskKind; /// @brief Kind of the drive. (Hard Drive, Solid State Drive, Optical
/// Drive, etc).
Kernel::UInt8 fEncoding; /// @brief Encoding of the filesystem. (UTF-8, UTF-16, etc).
Kernel::UInt64 fStartIND; /// @brief Start of the INode tree.
@@ -332,7 +332,7 @@ inline const Char* hefs_file_flags_to_string(UInt32 flags) noexcept {
}
} // namespace Kernel::Detail
-namespace Kernel {
+namespace Kernel::HeFS {
/// @brief HeFS filesystem parser class.
/// @details This class is used to parse the HeFS filesystem.
class HeFileSystemParser final {
@@ -351,17 +351,13 @@ class HeFileSystemParser final {
/// @brief Make a EPM+HeFS drive out of the disk.
/// @param drive The drive to write on.
/// @return If it was sucessful, see err_local_get().
- _Output Bool FormatEPM(_Input _Output DriveTrait* drive, _Input const Lba end_lba,
- _Input const Int32 flags, const Char* part_name);
-
- /// @brief Make a GPT+HeFS drive out of the disk.
- /// @param drive The drive to write on.
- /// @return If it was sucessful, see err_local_get().
- _Output Bool FormatGPT(_Input _Output DriveTrait* drive, _Input const Lba end_lba,
- _Input const Int32 flags, const Char* part_name);
+ _Output Bool Format(_Input _Output DriveTrait* drive, _Input const Int32 flags,
+ const Utf16Char* part_name);
public:
UInt32 mDriveIndex{MountpointInterface::kDriveIndexA}; /// @brief The drive index which this
/// filesystem is mounted on.
};
-} // namespace Kernel \ No newline at end of file
+
+Boolean fs_init_hefs(Void) noexcept;
+} // namespace Kernel::HeFS \ No newline at end of file